//=============================================================================
// (c) Copyright 2015 Diamond Systems Corporation. Use of this source code
// is subject to the terms of Diamond Systems' Software License Agreement.
// Diamond Systems provides no warranty of proper performance if this
// source code is modified.
//
// File: AthenaIIIWatchdog.c   v1.00
//
//
// Dependency : Universal Driver version 7.00
//    DSCUD.H - Include file.
//    
//    LIBDSCUD-7.00.a - Library file for Linux 2.6.29-3.x
//      
//    DSCUD.LIB - Static library file for Windows 
//
// Description: This sample code demonstrates the usage of UD functions
//				dscWatchdogTrigger(), dscWatchdogTrigger(), dscWatchdogDisable().
//              This sample code describes the usage for Athena III SBC. The
//              current configuration of the code demonstrates how to reset
//              the board after the counter finishes.
// ************************* History ********************
// Version		Engineer		Date		Description
// 1.0			James Moore		07/30/09	Created.
//=============================================================================
#include "DSCUD_demo_def.h"
// var declarations
BYTE result; // returned error code
DSCB dscb;   // handle used to refer to the board
DSCCB dsccb; // structure containing board settings
ERRPARAMS errorParams;  // structure for returning error code and error string
float floatBuff;        // temp variable of size float
BYTE value;
int counter0,counter1=0;
char input_buffer[20]; // Buffer for parsing user character input.
int AthenaWatchDogStop();
int AthenaWatchDogCounterLoad();
int AthenaWatchDogStart();
int AthenaWatchDogCounterReload();

int main()
{
	if ( dscInit( DSC_VERSION ) != DE_NONE )
	{
		dscGetLastError(&errorParams);
		fprintf ( stderr, "dscInit error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );
		return 0;
	}
	dsccb.base_address = 0x500;

	if ( dscInitBoard ( DSC_RAW, &dsccb, &dscb ) != DE_NONE )
	{
		dscGetLastError(&errorParams);
		fprintf( stderr, "dscInitBoard error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );
		return 0;
	}
	printf("\nAthena III Watch Dog Timer Demo");
	
	if(AthenaWatchDogStop()==-1)
	{
		return 0;
	}
	if(AthenaWatchDogCounterLoad()==-1)
	{
		return 0;
	}
	
	printf("\nPress any to key to start the watch dog timer");
	getchar();
	if(AthenaWatchDogStart()==-1)
	{
		return 0;
	}
	printf("\nPress any to key to reload the counters");
	getchar();
	if(AthenaWatchDogCounterReload()==-1)
	{
		return 0;
	}
	
	printf("\nPress any to key to stop the watch dog timer");
	getchar();
	if(AthenaWatchDogStop()==-1)
	{
		return 0;
	}

	dscFree();
	printf ( "\nAthena III Watch Dog Timer Demo Completed");

	return 0;
}

int AthenaWatchDogStart()
{
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	dscOutp((0x500+0x18),0x02);
	return 0;
}
int AthenaWatchDogCounterLoad()
{
	printf ("\nEnter value for counter 0(maximum of 1024 seconds,minimum-5 Default-60):");
	fgets ( input_buffer, 20, stdin );
	if ( input_buffer[0] == '\n' )
	{
		counter0 = 60;
	}
	else
	{
		sscanf ( input_buffer, "%d", &counter0 );	
	}
	counter0=((counter0)*(0x3E8));
	
	printf ("Enter value for counter 1(maximum of 1024 seconds,minimum-5 Default-60):");
	fgets ( input_buffer, 20, stdin );
	if ( input_buffer[0] == '\n' )
	{
		counter1 = 60;
	}
	else
	{
	     sscanf ( input_buffer, "%d", &counter1 );		
	}
	counter1=((counter1)*(0x3E8));

	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	
	value= (counter0 & 0xFF);
	dscOutp(0x500,value);
	
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	
	value= ((counter0>>8)& 0xFF);
	dscOutp(0x501,value);
	
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	
	value= ((counter0>>16)& 0xFF);
	dscOutp(0x502,value);

	
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);	
	value= (counter1& 0xFF);
	dscOutp(0x504,value);
	
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	
	value= ((counter1>>8)& 0xFF);
	dscOutp(0x505,value);
	
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	
	value= ((counter1>>16)& 0xFF);
	dscOutp(0x506,value);
	
	return 0;
}

int AthenaWatchDogCounterReload()
{
	printf("Inside Reload\n");
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	dscOutp((0x500+0x0D),0x01);
	
	return 0;
}

int AthenaWatchDogStop()
{
	dscOutp((0x500+0x0C),0x80);
	dscOutp((0x500+0x0C),0x86);
	dscOutp((0x500+0x18),0x00);
	
	return 0;
	
}

#ifdef _WIN32_WCE
int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	main();

	return 0;
}

#endif
